@@ -34,11 +34,11 @@ Wrapper around the standard Python mail library.
 import logging
 import re
 import smtplib
-
+import ssl
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.mime.image import MIMEImage
-
+from future.utils import string_types
 
 class VscMailError(Exception):
     """Raised if the sending of an email fails for some reason."""
@@ -47,7 +47,7 @@ class VscMailError(Exception):
         """Initialisation.
 
         @type mail_host: string
-        @type mail_to: string
+        @type mail_to: list of strings (or string, but deprecated)
         @type mail_from: string
         @type mail_subject: string
         @type err: Exception subclass
@@ -68,30 +68,54 @@ class VscMailError(Exception):
 class VscMail(object):
     """Class providing functionality to send out mail."""
 
-    def __init__(self, mail_host=None):
-        self.mail_host = mail_host
+    def __init__(
+        self,
+        mail_host='',
+        mail_port=0,
+        smtp_auth_user=None,
+        smtp_auth_password=None,
+        smtp_use_starttls=False):
 
-    def _send(self,
-              mail_from,
-              mail_to,
-              mail_subject,
-              msg):
+        self.mail_host = mail_host
+        self.mail_port = mail_port
+        self.smtp_auth_user = smtp_auth_user
+        self.smtp_auth_password = smtp_auth_password
+        self.smtp_use_starttls = smtp_use_starttls
+
+    def _connect(self):
+        """
+        Connect to the mail host on the given port.
+
+        If provided, use authentication and TLS.
+        """
+        logging.debug("Using mail host %s, mail port %d", self.mail_host, self.mail_port)
+        s = smtplib.SMTP(host=self.mail_host, port=self.mail_port)
+
+        if self.smtp_use_starttls:
+            context = ssl.create_default_context()
+            s.starttls(context=context)
+            logging.debug("Started TLS connection")
+
+        if self.smtp_auth_user and self.smtp_auth_password:
+            s.login(user=self.smtp_auth_user, password=self.smtp_auth_password)
+            logging.debug("Authenticated")
+
+        s.connect()
+
+        return s
+
+    def _send(self, mail_from, mail_to, mail_subject, msg):
         """Actually send the mail.
 
         @type mail_from: string representing the sender.
-        @type mail_to: string representing the recipient.
+        @type mail_to: list of strings (or string, but deprecated) representing the recipient.
         @type mail_subject: string representing the subject.
         @type msg: MIME message.
         """
 
         try:
-            if self.mail_host:
-                logging.debug("Using %s as the mail host", self.mail_host)
-                s = smtplib.SMTP(self.mail_host)
-            else:
-                logging.debug("Using the default mail host")
-                s = smtplib.SMTP()
-                s.connect()
+            s = self._connect()
+
             try:
                 s.sendmail(mail_from, mail_to, msg.as_string())
             except smtplib.SMTPHeloError as err:
@@ -105,47 +129,74 @@ class VscMail(object):
                 raise
             except smtplib.SMTPDataError as err:
                 raise
+
         except smtplib.SMTPConnectError as err:
             logging.exception("Cannot connect to the SMTP host %s", self.mail_host)
-            raise VscMailError(mail_host=self.mail_host,
-                               mail_to=mail_to,
-                               mail_from=mail_from,
-                               mail_subject=mail_subject,
-                               err=err)
+            raise VscMailError(
+                mail_host=self.mail_host,
+                mail_to=mail_to,
+                mail_from=mail_from,
+                mail_subject=mail_subject,
+                err=err)
         except Exception as err:
             logging.exception("Some unknown exception occurred in VscMail.sendTextMail. Raising a VscMailError.")
-            raise VscMailError(mail_host=self.mail_host,
-                               mail_to=mail_to,
-                               mail_from=mail_from,
-                               mail_subject=mail_subject,
-                               err=err)
+            raise VscMailError(
+                mail_host=self.mail_host,
+                mail_to=mail_to,
+                mail_from=mail_from,
+                mail_subject=mail_subject,
+                err=err)
+        else:
+            s.quit()
 
-    def sendTextMail(self,
-                     mail_to,
-                     mail_from,
-                     reply_to,
-                     mail_subject,
-                     message):
+    def sendTextMail(
+        self,
+        mail_to,
+        mail_from,
+        reply_to,
+        mail_subject,
+        message,
+        cc=None,
+        bcc=None):
         """Send out the given message by mail to the given recipient(s).
 
-        @type mail_to: string or list of strings
+        @type mail_to: list
         @type mail_from: string
         @type reply_to: string
         @type mail_subject: string
         @type message: string
+        @type cc: list
+        @type bcc: list
 
-        @param mail_to: a valid recipient email address
+        @param mail_to: a list of valid email addresses
         @param mail_from: a valid sender email address.
         @param reply_to: a valid email address for the (potential) replies.
         @param mail_subject: the subject of the email.
         @param message: the body of the mail.
+        @param cc: a list of valid CC email addresses
+        @param bcc: a list of valid BCC email addresses
         """
+
+        # deprecated: single email as string
+        if isinstance(mail_to, string_types):
+            mail_to = [mail_to]
+
         logging.info("Sending mail [%s] to %s.", mail_subject, mail_to)
 
         msg = MIMEText(message)
         msg['Subject'] = mail_subject
         msg['From'] = mail_from
-        msg['To'] = mail_to
+        msg['To'] = ','.join(mail_to)
+
+        if cc:
+            logging.info("Sending mail [%s] in CC to %s.", mail_subject, cc)
+            msg['Cc'] = cc
+            mail_to.extend(cc)
+
+        if bcc:
+            logging.info("Sending mail [%s] in BCC to %s.", mail_subject, bcc)
+            # do *not* set msg['Bcc'] to avoid leaking the BCC email address to all recipients
+            mail_to.extend(bcc)
 
         if reply_to is None:
             reply_to = mail_from
@@ -174,21 +225,24 @@ class VscMail(object):
 
         return html
 
-    def sendHTMLMail(self,
-                     mail_to,
-                     mail_from,
-                     reply_to,
-                     mail_subject,
-                     html_message,
-                     text_alternative,
-                     images=None,
-                     css=None):
+    def sendHTMLMail(
+        self,
+        mail_to,
+        mail_from,
+        reply_to,
+        mail_subject,
+        html_message,
+        text_alternative,
+        images=None,
+        css=None,
+        cc=None,
+        bcc=None):
         """
         Send an HTML email message, encoded in a MIME/multipart message.
 
         The images and css are included in the message, and should be provided separately.
 
-        @type mail_to: string or list of strings
+        @type mail_to: list
         @type mail_from: string
         @type reply_to: string
         @type mail_subject: string
@@ -196,8 +250,10 @@ class VscMail(object):
         @type text_alternative: string
         @type images: list of strings
         @type css: string
+        @type cc: list
+        @type bcc: list
 
-        @param mail_to: a valid recipient email addresses.
+        @param mail_to: a list of valid email addresses
         @param mail_from: a valid sender email address.
         @param reply_to: a valid email address for the (potential) replies.
         @param html_message: the actual payload, body of the mail
@@ -205,13 +261,31 @@ class VscMail(object):
         @param images: the images that are referenced in the HTML body. These should be available as files on the
                       filesystem in the directory where the script runs. Caveat: assume jpeg image type.
         @param css: CSS definitions
+        @param cc: a list of valid CC email addresses
+        @param bcc: a list of valid BCC email addresses
         """
 
+        # deprecated: single email as string
+        if isinstance(mail_to, string_types):
+            mail_to = [mail_to]
+
+        logging.info("Sending mail [%s] to %s.", mail_subject, mail_to)
+
         # Create message container - the correct MIME type is multipart/alternative.
         msg_root = MIMEMultipart('alternative')
         msg_root['Subject'] = mail_subject
         msg_root['From'] = mail_from
-        msg_root['To'] = mail_to
+        msg_root['To'] = ','.join(mail_to)
+
+        if cc:
+            logging.info("Sending mail [%s] in CC to %s.", mail_subject, cc)
+            msg_root['Cc'] = cc
+            mail_to.extend(cc)
+
+        if bcc:
+            logging.info("Sending mail [%s] in BCC to %s.", mail_subject, bcc)
+            # do *not* set msg_root['Bcc'] to avoid leaking the BCC email address to all recipients
+            mail_to.extend(bcc)
 
         if reply_to is None:
             reply_to = mail_from
@@ -222,7 +296,7 @@ class VscMail(object):
 
         # Create the body of the message (a plain-text and an HTML version).
         if images is not None:
-            html_message = self.replace_images_cid(html_message, images)
+            html_message = self._replace_images_cid(html_message, images)
 
         # Record the MIME types of both parts - text/plain and text/html_message.
         msg_plain = MIMEText(text_alternative, 'plain')
